==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/ooaofooa/component/ExecutableProperty.java <==
package io.ciera.tool.sql.ooaofooa.component;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.component.C_I;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperation;
import io.ciera.tool.sql.ooaofooa.component.InterfaceSignal;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameter;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;

import ooaofooa.datatypes.IFDirectionType;


public interface ExecutableProperty extends IModelInstance<ExecutableProperty,Sql> {

    // attributes
    public void setId( UniqueId m_Id ) throws XtumlException;
    public UniqueId getId() throws XtumlException;
    public void setInterface_Id( UniqueId ref_Interface_Id ) throws XtumlException;
    public UniqueId getInterface_Id() throws XtumlException;
    public void setDirection( IFDirectionType m_Direction ) throws XtumlException;
    public IFDirectionType getDirection() throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public String getDescrip() throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public int getNumb() throws XtumlException;


    // operations


    // selections
    default public void setR4003_provides_signature_of_C_I( C_I inst ) {}
    public C_I R4003_provides_signature_of_C_I() throws XtumlException;
    default public void setR4004_is_a_InterfaceOperation( InterfaceOperation inst ) {}
    public InterfaceOperation R4004_is_a_InterfaceOperation() throws XtumlException;
    default public void setR4004_is_a_InterfaceSignal( InterfaceSignal inst ) {}
    public InterfaceSignal R4004_is_a_InterfaceSignal() throws XtumlException;
    default public void addR4006_is_parameter_to_PropertyParameter( PropertyParameter inst ) {}
    default public void removeR4006_is_parameter_to_PropertyParameter( PropertyParameter inst ) {}
    public PropertyParameterSet R4006_is_parameter_to_PropertyParameter() throws XtumlException;
    default public void addR4500_is_implemented_by_RequiredExecutableProperty( RequiredExecutableProperty inst ) {}
    default public void removeR4500_is_implemented_by_RequiredExecutableProperty( RequiredExecutableProperty inst ) {}
    public RequiredExecutablePropertySet R4500_is_implemented_by_RequiredExecutableProperty() throws XtumlException;
    default public void addR4501_is_implemented_by_ProvidedExecutableProperty( ProvidedExecutableProperty inst ) {}
    default public void removeR4501_is_implemented_by_ProvidedExecutableProperty( ProvidedExecutableProperty inst ) {}
    public ProvidedExecutablePropertySet R4501_is_implemented_by_ProvidedExecutableProperty() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/component/ExecutableProperty.java <==
package io.ciera.tool.sql.ooaofooa.component;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.interfaces.Message;
import io.ciera.tool.sql.ooaofooa.component.C_I;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperation;
import io.ciera.tool.sql.ooaofooa.component.InterfaceSignal;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameter;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutableProperty;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;

import ooaofooa.datatypes.IFDirectionType;


public interface ExecutableProperty extends IModelInstance<ExecutableProperty,Sql> {

    // attributes
    public UniqueId getId() throws XtumlException;
    public void setId( UniqueId m_Id ) throws XtumlException;
    public UniqueId getInterface_Id() throws XtumlException;
    public void setInterface_Id( UniqueId ref_Interface_Id ) throws XtumlException;
    public IFDirectionType getDirection() throws XtumlException;
    public void setDirection( IFDirectionType m_Direction ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public String getDescrip() throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public int getNumb() throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;


    // operations


    // selections
    default public void setR4003_provides_signature_of_C_I( C_I inst ) {}
    public C_I R4003_provides_signature_of_C_I() throws XtumlException;
    default public void setR4004_is_a_InterfaceOperation( InterfaceOperation inst ) {}
    public InterfaceOperation R4004_is_a_InterfaceOperation() throws XtumlException;
    default public void setR4004_is_a_InterfaceSignal( InterfaceSignal inst ) {}
    public InterfaceSignal R4004_is_a_InterfaceSignal() throws XtumlException;
    default public void addR4006_is_parameter_to_PropertyParameter( PropertyParameter inst ) {}
    default public void removeR4006_is_parameter_to_PropertyParameter( PropertyParameter inst ) {}
    public PropertyParameterSet R4006_is_parameter_to_PropertyParameter() throws XtumlException;
    default public void addR4500_is_implemented_by_RequiredExecutableProperty( RequiredExecutableProperty inst ) {}
    default public void removeR4500_is_implemented_by_RequiredExecutableProperty( RequiredExecutableProperty inst ) {}
    public RequiredExecutablePropertySet R4500_is_implemented_by_RequiredExecutableProperty() throws XtumlException;
    default public void addR4501_is_implemented_by_ProvidedExecutableProperty( ProvidedExecutableProperty inst ) {}
    default public void removeR4501_is_implemented_by_ProvidedExecutableProperty( ProvidedExecutableProperty inst ) {}
    public ProvidedExecutablePropertySet R4501_is_implemented_by_ProvidedExecutableProperty() throws XtumlException;
    default public void setR4761_Message( Message inst ) {}
    public Message R4761_Message() throws XtumlException;


}
